Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/matomo-org/matomo.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorBenaka Moorthi <benaka.moorthi@gmail.com>2013-08-12 07:11:02 +0400
committerBenaka Moorthi <benaka.moorthi@gmail.com>2013-08-12 07:11:02 +0400
commita8439b11e5ba0e4cc85881158e2285d394c77712 (patch)
treecef5bffc3b8a240c9155b426d097b6539ff87044 /plugins/CoreHome/javascripts/popover.js
parent93e2098318669cbcfad468e2aa94f56f03952531 (diff)
Refs #3089, make minimum top of popover 15px instead of 106px.
Diffstat (limited to 'plugins/CoreHome/javascripts/popover.js')
-rw-r--r--plugins/CoreHome/javascripts/popover.js4
1 files changed, 2 insertions, 2 deletions
diff --git a/plugins/CoreHome/javascripts/popover.js b/plugins/CoreHome/javascripts/popover.js
index 40d1649253..8cb4afe60b 100644
--- a/plugins/CoreHome/javascripts/popover.js
+++ b/plugins/CoreHome/javascripts/popover.js
@@ -213,11 +213,11 @@ var Piwik_Popover = (function () {
* @param {string} [dialogClass] css class to add to dialog
*/
createPopupAndLoadUrl: function (url, loadingName, dialogClass) {
// make sure the minimum top position of the popover is 106px
var ensureMinimumTop = function () {
var popoverContainer = $('#Piwik_Popover').parent();
if (popoverContainer.position().top < 106) {
- popoverContainer.css('top', '106px');
+ popoverContainer.css('top', '15px');
}
};
@@ -213,11 +213,11 @@ var Piwik_Popover = (function () {
*/
createPopupAndLoadUrl: function (url, loadingName, dialogClass) {
- // make sure the minimum top position of the popover is 106px
+ // make sure the minimum top position of the popover is 15px
var ensureMinimumTop = function () {
var popoverContainer = $('#Piwik_Popover').parent();